@@ -70,5 +70,8 @@ typedef CTX* Fl__HorSlider;
 typedef CTX* Fl__Scrollbar;
 typedef CTX* Fl__ValueSlider;
 typedef CTX* Fl__HorValueSlider;
+typedef CTX* Fl__Tabs;
+typedef CTX* Fl__Output;
+typedef CTX* Fl__MultilineOutput;
 
 #endif // #ifndef fltk_pm_h
